@@ -16,18 +16,25 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.1 2004/01/31 23:29:42 chpe Exp $
+ *  $Id: extension.c,v 1.2 2004/08/26 19:51:44 chpe Exp $
  */
 
 #include "ephy-certificates-extension.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
+#include <glib/gi18n-lib.h>
 
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
 	LOG ("Registering EphySampleExtension")
 
+#ifdef ENABLE_NLS
+       /* Initialise the i18n stuff */
+        bindtextdomain (GETTEXT_PACKAGE, EPHY_PLUGINS_LOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
+#endif /* ENABLE_NLS */
+
 	return ephy_certificates_extension_register_type (module);
 }
