@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dashboard-extension.c,v 1.8 2004/02/24 17:47:14 chpe Exp $
+ *  $Id: ephy-dashboard-extension.c,v 1.9 2004/09/12 16:48:16 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -221,7 +221,7 @@ impl_detach_window (EphyExtension *ext,
 static void
 ephy_dashboard_extension_init (EphyDashboardExtension *extension)
 {
-	extension->priv = EPHY_DASHBOARD_EXTENSION_GET_PRIVATE (extension);
+/*	extension->priv = EPHY_DASHBOARD_EXTENSION_GET_PRIVATE (extension);*/
 
 	LOG ("EphyDashboardExtension initialising")
 }
@@ -240,5 +240,5 @@ ephy_dashboard_extension_class_init (EphyDashboardExtensionClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	g_type_class_add_private (object_class, sizeof (EphyDashboardExtensionPrivate));
+/*	g_type_class_add_private (object_class, sizeof (EphyDashboardExtensionPrivate));*/
 }
