@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003  Marco Pesenti Gritti
- *  Copyright (C) 2003  Christian Persch
+ *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-move-menu.c,v 1.4.2.1 2004/02/01 14:25:01 chpe Exp $
+ *  $Id: ephy-tab-move-menu.c,v 1.7 2004/09/07 04:17:48 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -133,7 +133,6 @@ move_cb (GtkAction *action,
 	EphyWindow *src_win = menu->priv->window;
 	EphyWindow *dest_win;
 	EphyTab *tab;
-	EphyEmbed *embed;
 	GtkWidget *src_nb, *dest_nb;
 
 	dest_win = get_window_from_action (action);
@@ -143,13 +142,12 @@ move_cb (GtkAction *action,
 
 	tab = ephy_window_get_active_tab (src_win);
 	g_return_if_fail (EPHY_IS_TAB (tab));
-	embed = ephy_tab_get_embed (tab);
 
 	src_nb = ephy_window_get_notebook (src_win);
 	dest_nb = ephy_window_get_notebook (dest_win);
 
-	ephy_notebook_move_page (EPHY_NOTEBOOK (src_nb), EPHY_NOTEBOOK (dest_nb),
-				 GTK_WIDGET (embed), -1);
+	ephy_notebook_move_tab (EPHY_NOTEBOOK (src_nb), EPHY_NOTEBOOK (dest_nb),
+				tab, -1);
 
 	ephy_window_jump_to_tab (dest_win, tab);
 }
@@ -266,7 +264,8 @@ update_tab_move_menu_cb (GtkAction *dummy,
 }
 
 static void
-ephy_tab_move_menu_set_window (EphyTabMoveMenu *menu, EphyWindow *window)
+ephy_tab_move_menu_set_window (EphyTabMoveMenu *menu,
+			       EphyWindow *window)
 {
 	GtkAction *action;
 	GtkActionGroup *action_group;
@@ -341,6 +340,7 @@ static void
 ephy_tab_move_menu_finalize (GObject *object)
 {
 	EphyTabMoveMenu *menu = EPHY_TAB_MOVE_MENU (object); 
+
 	GtkActionGroup *action_group;
 	GtkAction *action;
 
@@ -358,6 +358,11 @@ ephy_tab_move_menu_finalize (GObject *object)
 
 	g_signal_handlers_disconnect_by_func (action, G_CALLBACK (update_tab_move_menu_cb), menu);
 */
+	if (menu->priv->merge_id != 0)
+	{
+		gtk_ui_manager_remove_ui (menu->priv->manager,
+					  menu->priv->merge_id);
+	}
 	if (menu->priv->action_group != NULL)
 	{
 		g_object_unref (menu->priv->action_group);
