@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu-extension.c,v 1.4 2004/02/24 17:47:23 chpe Exp $
+ *  $Id: ephy-tabs-menu-extension.c,v 1.5 2004/09/07 04:17:48 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -94,7 +94,7 @@ static void
 impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
-	/* nothing to do */
+	g_object_set_data (G_OBJECT (window), "ephy-tab-move-menu", NULL);
 }
 
 static void
